==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/gwt/serder/ConversationMessageRefGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ConversationMessageRefGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.Conversation.MessageRef> {

	public ConversationMessageRefGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.Conversation.MessageRef deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.Conversation.MessageRef ret = new net.bluemind.backend.mail.api.Conversation.MessageRef();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.Conversation.MessageRef ret, JSONObject json) {

		JSONValue folderUidJSON = json.get("folderUid");
		ret.folderUid =  GwtSerDerUtils.STRING.deserialize(folderUidJSON);
		JSONValue itemIdJSON = json.get("itemId");
		ret.itemId =  GwtSerDerUtils.LONG.deserialize(itemIdJSON);
		JSONValue dateJSON = json.get("date");
		ret.date =  GwtSerDerUtils.DATE.deserialize(dateJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.Conversation.MessageRef o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.Conversation.MessageRef o, JSONObject ret) {

		ret.put("folderUid",  GwtSerDerUtils.STRING.serialize( o.folderUid ));
		ret.put("itemId",  GwtSerDerUtils.LONG.serialize( o.itemId ));
		ret.put("date",  GwtSerDerUtils.DATE.serialize( o.date ));
	}
}

==> net.bluemind.p2.platform-5.4.2696.zip: net/bluemind/backend/mail/api/gwt/serder/ConversationMessageRefGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ConversationMessageRefGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.Conversation.MessageRef> {

	public ConversationMessageRefGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.Conversation.MessageRef deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.Conversation.MessageRef ret = new net.bluemind.backend.mail.api.Conversation.MessageRef();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.Conversation.MessageRef ret, JSONObject json) {
		JSONValue folderUidJSON = json.get("folderUid");
		ret.folderUid =  GwtSerDerUtils.STRING.deserialize(folderUidJSON);
		JSONValue itemIdJSON = json.get("itemId");
		ret.itemId =  GwtSerDerUtils.LONG.deserialize(itemIdJSON);
		JSONValue dateJSON = json.get("date");
		ret.date =  GwtSerDerUtils.DATE.deserialize(dateJSON);
	}

	public void deserializeTo(net.bluemind.backend.mail.api.Conversation.MessageRef ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("folderUid")) {
			JSONValue folderUidJSON = json.get("folderUid");
			ret.folderUid =  GwtSerDerUtils.STRING.deserialize(folderUidJSON);
		}
		if (!childPropertiesToIgnore.contains("itemId")) {
			JSONValue itemIdJSON = json.get("itemId");
			ret.itemId =  GwtSerDerUtils.LONG.deserialize(itemIdJSON);
		}
		if (!childPropertiesToIgnore.contains("date")) {
			JSONValue dateJSON = json.get("date");
			ret.date =  GwtSerDerUtils.DATE.deserialize(dateJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.Conversation.MessageRef o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.Conversation.MessageRef o, JSONObject ret) {

		ret.put("folderUid",  GwtSerDerUtils.STRING.serialize( o.folderUid ));
		ret.put("itemId",  GwtSerDerUtils.LONG.serialize( o.itemId ));
		ret.put("date",  GwtSerDerUtils.DATE.serialize( o.date ));
	}

	public void serializeTo(net.bluemind.backend.mail.api.Conversation.MessageRef o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("folderUid")) {
			ret.put("folderUid",  GwtSerDerUtils.STRING.serialize( o.folderUid ));
		}
		if (!childPropertiesToIgnore.contains("itemId")) {
			ret.put("itemId",  GwtSerDerUtils.LONG.serialize( o.itemId ));
		}
		if (!childPropertiesToIgnore.contains("date")) {
			ret.put("date",  GwtSerDerUtils.DATE.serialize( o.date ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
